@@ -13,7 +13,6 @@ seconds to allow some time to pass between calls to check the modify
 time on files.
 """
 
-import io
 import os
 import sys
 import shutil
@@ -94,7 +93,7 @@ class TestBasics:
         """Test compatibility with ordinary strings."""
         x = Path('xyzzy')
         assert x == 'xyzzy'
-        assert x == str('xyzzy')
+        assert x == 'xyzzy'
 
         # sorting
         items = [Path('fhj'), Path('fgh'), 'E', Path('d'), 'A', Path('B'), 'c']
@@ -301,12 +300,15 @@ class TestBasics:
 
 
 class TestReadWriteText:
-    @pytest.mark.filterwarnings('ignore:Writing bytes in write_text')
     def test_read_write(self, tmpdir):
         file = path.Path(tmpdir) / 'filename'
-        file.write_text('hello world')
-        assert file.read_text() == 'hello world'
+        file.write_text('hello world', encoding='utf-8')
+        assert file.read_text(encoding='utf-8') == 'hello world'
         assert file.read_bytes() == b'hello world'
+
+    @pytest.mark.filterwarnings('ignore:Writing bytes in write_text')
+    def test_write_text_bytes(self, tmpdir):
+        file = path.Path(tmpdir) / 'filename'
         file.write_text(b'hello world')
 
 
@@ -316,7 +318,7 @@ class TestPerformance:
         args = [sys.executable, '-m', 'timeit', '-n', '1', '-r', '1', '-u', 'usec'] + [
             cmd
         ]
-        res = subprocess.check_output(args, universal_newlines=True)
+        res = subprocess.check_output(args, text=True, encoding='utf-8')
         dur = re.search(r'(\d+) usec per loop', res).group(1)
         return datetime.timedelta(microseconds=int(dur))
 
@@ -334,6 +336,7 @@ class TestPerformance:
 
 
 class TestOwnership:
+    @pytest.mark.skipif('platform.system() == "Windows" and sys.version_info > (3, 12)')
     def test_get_owner(self):
         Path('/').get_owner()
 
@@ -343,7 +346,7 @@ class TestLinks:
         target = Path(tmpdir) / 'target'
         target.write_text('hello', encoding='utf-8')
         link = target.link(Path(tmpdir) / 'link')
-        assert link.read_text() == 'hello'
+        assert link.read_text(encoding='utf-8') == 'hello'
 
     def test_symlink_none(self, tmpdir):
         root = Path(tmpdir)
@@ -472,9 +475,8 @@ class TestScratchDir:
             assert t0 <= ct <= t1
 
         time.sleep(threshold * 2)
-        fobj = open(f, 'ab')
-        fobj.write('some bytes'.encode('utf-8'))
-        fobj.close()
+        with open(f, 'ab') as fobj:
+            fobj.write(b'some bytes')
 
         time.sleep(threshold * 2)
         t2 = time.time() - threshold
@@ -534,9 +536,8 @@ class TestScratchDir:
         # Try a test with 20 files
         files = [d / ('%d.txt' % i) for i in range(20)]
         for f in files:
-            fobj = open(f, 'w')
-            fobj.write('some text\n')
-            fobj.close()
+            with open(f, 'w', encoding='utf-8') as fobj:
+                fobj.write('some text\n')
         try:
             files2 = d.listdir()
             files.sort()
@@ -549,7 +550,7 @@ class TestScratchDir:
 
     @pytest.fixture
     def bytes_filename(self, tmpdir):
-        name = r'r\xe9\xf1emi'.encode('latin-1')
+        name = br'r\xe9\xf1emi'
         base = str(tmpdir).encode('ascii')
         try:
             with open(os.path.join(base, name), 'wb'):
@@ -635,9 +636,8 @@ class TestScratchDir:
         testA.mkdir()
         testB.mkdir()
 
-        f = open(testFile, 'w')
-        f.write('x' * 10000)
-        f.close()
+        with open(testFile, 'w', encoding='utf-8') as f:
+            f.write('x' * 10000)
 
         # Test simple file copying.
         testFile.copyfile(testCopy)
@@ -738,7 +738,7 @@ class TestScratchDir:
         stripped = [line.replace('\n', '') for line in expectedLines]
 
         # write bytes manually to file
-        with io.open(p, 'wb') as strm:
+        with open(p, 'wb') as strm:
             strm.write(given.encode(encoding))
 
         # test all 3 path read-fully functions, including
@@ -819,8 +819,8 @@ class TestScratchDir:
         p = (TempDir() / 'test.txt').touch()
         txt = "0123456789"
         size = 5
-        p.write_text(txt)
-        for i, chunk in enumerate(p.chunks(size)):
+        p.write_text(txt, encoding='utf-8')
+        for i, chunk in enumerate(p.chunks(size, encoding='utf-8')):
             assert chunk == txt[i * size : i * size + size]
 
         assert i == len(txt) / size - 1
@@ -899,7 +899,7 @@ class TestMergeTree:
         self.subdir_a.mkdir()
         self.subdir_b.mkdir()
 
-        with open(self.test_file, 'w') as f:
+        with open(self.test_file, 'w', encoding='utf-8') as f:
             f.write('x' * 10000)
 
         self.test_file.symlink(self.test_link)
@@ -912,18 +912,20 @@ class TestMergeTree:
     def test_with_nonexisting_dst_kwargs(self):
         self.subdir_a.merge_tree(self.subdir_b, symlinks=True)
         assert self.subdir_b.isdir()
-        expected = set(
-            (self.subdir_b / self.test_file.name, self.subdir_b / self.test_link.name)
-        )
+        expected = {
+            self.subdir_b / self.test_file.name,
+            self.subdir_b / self.test_link.name,
+        }
         assert set(self.subdir_b.listdir()) == expected
         self.check_link()
 
     def test_with_nonexisting_dst_args(self):
         self.subdir_a.merge_tree(self.subdir_b, True)
         assert self.subdir_b.isdir()
-        expected = set(
-            (self.subdir_b / self.test_file.name, self.subdir_b / self.test_link.name)
-        )
+        expected = {
+            self.subdir_b / self.test_file.name,
+            self.subdir_b / self.test_link.name,
+        }
         assert set(self.subdir_b.listdir()) == expected
         self.check_link()
 
@@ -934,19 +936,17 @@ class TestMergeTree:
         self.test_link.remove()
         test_new = self.subdir_a / 'newfile.txt'
         test_new.touch()
-        with open(self.test_file, 'w') as f:
+        with open(self.test_file, 'w', encoding='utf-8') as f:
             f.write('x' * 5000)
 
         self.subdir_a.merge_tree(self.subdir_b, True)
 
         assert self.subdir_b.isdir()
-        expected = set(
-            (
-                self.subdir_b / self.test_file.name,
-                self.subdir_b / self.test_link.name,
-                self.subdir_b / test_new.name,
-            )
-        )
+        expected = {
+            self.subdir_b / self.test_file.name,
+            self.subdir_b / self.test_link.name,
+            self.subdir_b / test_new.name,
+        }
         assert set(self.subdir_b.listdir()) == expected
         self.check_link()
         assert len(Path(self.subdir_b / self.test_file.name).bytes()) == 5000
@@ -968,11 +968,16 @@ class TestMergeTree:
         newer copies in the dest.
         """
         target = self.subdir_b / 'testfile.txt'
-        target.write_text('this is newer')
+        target.write_text('this is newer', encoding='utf-8')
         self.subdir_a.merge_tree(
             self.subdir_b, copy_function=path.only_newer(shutil.copy2)
         )
-        assert target.read_text() == 'this is newer'
+        assert target.read_text(encoding='utf-8') == 'this is newer'
+
+    def test_nested(self):
+        self.subdir_a.joinpath('subsub').mkdir()
+        self.subdir_a.merge_tree(self.subdir_b)
+        assert self.subdir_b.joinpath('subsub').isdir()
 
 
 class TestChdir:
@@ -1184,29 +1189,29 @@ class TestInPlace:
     @classmethod
     def create_reference(cls, tmpdir):
         p = Path(tmpdir) / 'document'
-        with p.open('w') as stream:
+        with p.open('w', encoding='utf-8') as stream:
             stream.write(cls.reference_content)
         return p
 
     def test_line_by_line_rewrite(self, tmpdir):
         doc = self.create_reference(tmpdir)
         # reverse all the text in the document, line by line
-        with doc.in_place() as (reader, writer):
+        with doc.in_place(encoding='utf-8') as (reader, writer):
             for line in reader:
                 r_line = ''.join(reversed(line.strip())) + '\n'
                 writer.write(r_line)
-        with doc.open() as stream:
+        with doc.open(encoding='utf-8') as stream:
             data = stream.read()
         assert data == self.reversed_content
 
     def test_exception_in_context(self, tmpdir):
         doc = self.create_reference(tmpdir)
         with pytest.raises(RuntimeError) as exc:
-            with doc.in_place() as (reader, writer):
+            with doc.in_place(encoding='utf-8') as (reader, writer):
                 writer.write(self.alternate_content)
                 raise RuntimeError("some error")
         assert "some error" in str(exc.value)
-        with doc.open() as stream:
+        with doc.open(encoding='utf-8') as stream:
             data = stream.read()
         assert 'Lorem' not in data
         assert 'lazy dog' in data
